# Datamizer for Python
This is a simple package that lets you change the sensitive data from a .CSV file creating a new file with fake data.


This allows the new data to be used for training, testing or analytics, without compromising private information.

## Installation

Run the following command to install the package:
```python
pip install datamizer
```

## Usage
